<?php
    
    namespace artbox\webcomment\controllers;
    
    use artbox\webcomment\models\CommentModel;
    use artbox\webcomment\models\CommentModelSearch;
    use artbox\webcomment\Module;
    use Yii;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;
    use yii\filters\AccessControl;
    
    class ManageController extends Controller
    {
        
        /**
         * Returns a list of behaviors that this component should behave as.
         *
         * @return array
         */
        public function behaviors()
        {
            return [
                'verbs' => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'index'  => [ 'get' ],
                        'update' => [
                            'get',
                            'post',
                        ],
                        'delete' => [ 'post' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'actions' => [
                                'login',
                                'error',
                            ],
                            'allow'   => true,
                        ],
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        
        /**
         * Lists all comments.
         *
         * @return mixed
         */
        public function actionIndex()
        {
            /**
             * @var Module $module
             */
            $module = \Yii::$app->getModule(Module::$name);
            if (!$module) {
                Module::registerMe();
            }
            $searchModel = new CommentModelSearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
            $commentModel = $module->commentModelClass;
            
            return $this->render(
                'index',
                [
                    'dataProvider' => $dataProvider,
                    'searchModel'  => $searchModel,
                    'commentModel' => $commentModel,
                ]
            );
        }
        
        /**
         * Updates an existing CommentModel model.
         * If update is successful, the browser will be redirected to the 'view' page.
         *
         * @param integer $id
         *
         * @return mixed
         */
        public function actionUpdate($id)
        {
            $model = $this->findModel($id);
            $model->scenario = $model::SCENARIO_ADMIN;
            
            if ($model->load(Yii::$app->request->post()) && $model->save()) {
                Yii::$app->session->setFlash(
                    'artbox_comment_success',
                    'Comment has been saved.'
                );
                return $this->redirect([ 'index' ]);
            }
            
            return $this->render(
                'update',
                [
                    'model' => $model,
                ]
            );
            
        }
    
        /**
         * Answer to particular comment from backend
         *
         * @param $id
         *
         * @return string|\yii\web\Response
         */
        public function actionAnswer($id)
        {
            $model = $this->findModel($id);
    
            $answer = new CommentModel(
                [
                    'scenario' => CommentModel::SCENARIO_ADMIN_ANSWER,
                ]
            );
            
            if ($answer->load(Yii::$app->request->post()) && $answer->save()) {
                Yii::$app->session->setFlash(
                    'artbox_comment_success',
                    'Comment has been saved.'
                );
                return $this->redirect([ 'index' ]);
            }
            
            return $this->render(
                'answer',
                [
                    'answer' => $answer,
                    'model'  => $model,
                ]
            );
        }
        
        /**
         * Deletes an existing CommentModel model.
         * If deletion is successful, the browser will be redirected to the 'index' page.
         *
         * @param integer $id
         *
         * @return mixed
         */
        public function actionDelete($id)
        {
            $this->findModel($id)
                 ->delete();
            Yii::$app->session->setFlash(
                'artbox_comment_success',
                Yii::t('artbox-comment', 'Comment has been deleted.')
            );
            return $this->redirect([ 'index' ]);
        }
        
        /**
         * Finds the CommentModel model based on its primary key value.
         * If the model is not found, a 404 HTTP exception will be thrown.
         *
         * @param integer $id
         *
         * @return CommentModel the loaded model
         * @throws NotFoundHttpException if the model cannot be found
         */
        protected function findModel($id)
        {
            if (( $model = CommentModel::findOne($id) ) !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException(
                    \Yii::t('artbox-comment', 'The requested page does not exist.')
                );
            }
        }
    }